@@ -62,6 +62,8 @@ Further Reading
 See http://sendapatch.se/projects/pylibmc/
 """
 
+from __future__ import with_statement
+
 import _pylibmc
 from Queue import Queue
 
@@ -113,6 +115,8 @@ class Client(_pylibmc.client):
 
         If *binary* is True, the binary memcached protocol is used.
         """
+        self.binary = binary
+        self.addresses = list(servers)
         addr_tups = []
         for server in servers:
             addr = server
@@ -135,6 +139,15 @@ class Client(_pylibmc.client):
             addr_tups.append((stype, addr, port))
         super(Client, self).__init__(servers=addr_tups, binary=binary)
 
+    def __repr__(self):
+        return "%s(%r, binary=%r)" % (self.__class__.__name__,
+                                      self.addresses, self.binary)
+
+    def __str__(self):
+        addrs = ", ".join(map(str, self.addresses))
+        return "<%s for %s, binary=%r>" % (self.__class__.__name__,
+                                           addrs, self.binary)
+
     def get_behaviors(self):
         """Gets the behaviors from the underlying C client instance.
 
@@ -272,6 +285,10 @@ if __name__ == "__main__":
     sys.stderr.write("pylibmc interactive shell\n\n")
     sys.stderr.write("Input list of servers, end by a blank line\n")
 
+    binary = False
+    if sys.argv[1:] == ["--binary"]:
+        binary = True
+
     while True:
         in_addr = raw_input("Address: ")
         if not in_addr:
@@ -279,5 +296,5 @@ if __name__ == "__main__":
     if not svr_addrs:
         svr_addrs.append("127.0.0.1")
 
-    mc = Client(svr_addrs)
+    mc = Client(svr_addrs, binary=binary)
     code.interact(banner="\nmc client available as `mc`", local={"mc": mc})
