@@ -1,4 +1,4 @@
-"""Tests. They want YOU!!
+r"""Tests. They want YOU!!
 
 
 Basic functionality.
@@ -74,17 +74,32 @@ True
 >>> c.get("hi")
 >>> c.set("hi", "loretta", int(time()) + 2)
 True
+>>> c.set_multi({"hi2": "charlotta"}, 1)
+[]
 >>> c.get("hi")
 'loretta'
+>>> c.get("hi2")
+'charlotta'
 >>> sleep(3.1)
->>> c.get("hi")
->>>
+>>> c.get("hi"), c.get("hi2")
+(None, None)
+
+See issue #1 ``http://github.com/lericson/pylibmc/issues/#issue/1`` -- delete
+should not accept a time argument.
+>>> c.delete("foo", 123)
+Traceback (most recent call last):
+  ...
+TypeError: delete() takes exactly 1 argument (2 given)
+>>> c.delete_multi(["foo"], time=123)
+Traceback (most recent call last):
+  ...
+TypeError: 'time' is an invalid keyword argument for this function
 
 Now for keys with funny types.
 >>> c.set(1, "hi")
 Traceback (most recent call last):
   ...
-TypeError: argument 1 must be string or read-only buffer, not int
+TypeError: argument 1 must be string, not int
 >>> c.get(1)
 Traceback (most recent call last):
   ...
@@ -109,7 +124,7 @@ Getting stats is fun!
 ...     while ks:
 ...         cks, ks = ks[:6], ks[6:]
 ...         print ", ".join(cks)
-localhost:11211 (0)
+127.0.0.1:11211 (0)
 pid, total_items, uptime, version, limit_maxbytes, rusage_user
 bytes_read, rusage_system, cmd_get, curr_connections, threads, total_connections
 cmd_set, curr_items, get_misses, evictions, bytes, connection_structures
@@ -182,6 +197,30 @@ True
 >>> c.delete("hello")
 True
 
+incr_multi
+>>> c.add_multi({'a': 1, 'b': 0, 'c': 4})
+[]
+>>> c.incr_multi(('a', 'b', 'c'), delta=1)
+>>> list(sorted(c.get_multi(('a', 'b', 'c')).items()))
+[('a', 2), ('b', 1), ('c', 5)]
+>>> c.delete_multi(('a', 'b', 'c'))
+True
+>>> c.add_multi({'a': 1, 'b': 0, 'c': 4}, key_prefix='x')
+[]
+>>> c.incr_multi(('a', 'b', 'c'), key_prefix='x', delta=5)
+>>> list(sorted(c.get_multi(('a', 'b', 'c'), key_prefix='x').items()))
+[('a', 6), ('b', 5), ('c', 9)]
+>>> c.delete_multi(('a', 'b', 'c'), key_prefix='x')
+True
+>>> c.add('a', 1)
+True
+>>> c.incr_multi(('a', 'b', 'c'), key_prefix='x', delta=1)
+Traceback (most recent call last):
+ ...
+NotFound: error 16 from memcached_increment: NOT FOUND
+>>> c.delete('xa')
+False
+
 Empty server lists are bad for your health.
 >>> c = _pylibmc.client([])
 Traceback (most recent call last):
@@ -210,6 +249,13 @@ Python-wrapped behaviors dict
 'fnv1a_32'
 >>> super(pylibmc.Client, pc).get_behaviors()["hash"]
 6
+
+Ormod's Zero-byte Adventure Story
+>>> bc = _pylibmc.client([test_server], binary=True)
+>>> bc.set("\0\0", "ORMOD")
+True
+>>> bc.get_multi(["\0\0"])
+{'\x00\x00': 'ORMOD'}
 """
 
 # Used to test pickling.
@@ -294,7 +340,12 @@ class TestCmemcached(unittest.TestCase):
         self.assertEqual(result, "I Do")
 # }}}
 
-test_server = (_pylibmc.server_type_tcp, "localhost", 11211)
+from os import environ
+
+test_server = (
+    _pylibmc.server_type_tcp,
+    str(environ.get("MEMCACHED_HOST", "127.0.0.1")),
+    int(environ.get("MEMCACHED_PORT", "11211")))
 
 def get_version(addr):
     (type_, host, port) = addr
